#
# spec file for package xalan-c
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _libname libxalan-c112
Name:           xalan-c
VCS: https://src.suse.de/SLFO-pool/xalan-c#5f17611de8c5355dfa900a3cdf8cd841fb4be9061c942dd7c20990ae65865cff
Version:        1.12
Release:        160000.1.7
Summary:        An XSLT Transformation Engine in C++
License:        Apache-2.0
Group:          Productivity/Publishing/XML
URL:            https://apache.github.io/xalan-c/
Source:         https://downloads.apache.org/xalan/xalan-c/sources/xalan_c-%{version}.tar.gz
BuildRequires:  Xerces-c-devel
BuildRequires:  cmake
BuildRequires:  gcc-c++
Provides:       Xalan-C = 1.11
Obsoletes:      Xalan-C < 1.11

%description
Xalan is an XSL processor for transforming XML documents into HTML,
text, or other XML document types. Xalan-C++ represents an almost
complete and robust C++ reference implementation of the W3C
Recommendations for XSL Transformations (XSLT) and the XML Path
Language (XPath).

%package -n %{_libname}
Summary:        An XSLT Transformation Engine in C++
Group:          System/Libraries
Provides:       libXalan-c111 = 1.11
Obsoletes:      libXalan-c111 < 1.11

%description -n %{_libname}
Xalan is an XSL processor for transforming XML documents into HTML,
text, or other XML document types. Xalan-C++ represents an almost
complete and robust C++ reference implementation of the W3C
Recommendations for XSL Transformations (XSLT) and the XML Path
Language (XPath).

%package -n libxalan-c-devel
Summary:        An XSLT Transformation Engine in C++ - Development Files
Group:          Development/Libraries/C and C++
Requires:       %{_libname} = %{version}
Provides:       Xalan-c-devel = %{version}
Obsoletes:      Xalan-c-devel < %{version}
Provides:       libXalan-c-devel = %{version}
Obsoletes:      libXalan-c-devel < %{version}

%description -n libxalan-c-devel
Xalan is an XSL processor for transforming XML documents into HTML,
text, or other XML document types. Xalan-C++ represents an almost
complete and a robust C++ reference implementation of the W3C
Recommendations for XSL Transformations (XSLT) and the XML Path
Language (XPath).

This package contains files needed for development with Xalanc

%prep
%setup -q -n xalan_c-%{version}

%build
%cmake
%cmake_build

%if 0
export XALANCROOT="${PWD}"
export XERCESROOT=%{_includedir}/xercesc/
export RPM_OPT_FLAGS
chmod a+x runConfigure
chmod a+x conf*
./runConfigure -p linux -c gcc -x g++ -t default -m inmem -b "%{__isa_bits}" -P %{_prefix} -C --libdir="%{_libdir}"
%make_build
%endif

%install
%cmake_install

%post   -n %{_libname} -p /sbin/ldconfig
%postun -n %{_libname} -p /sbin/ldconfig

%files
%license LICENSE
%doc KEYS NOTICE
%{_bindir}/Xalan

%files -n %{_libname}
%{_libdir}/libxalan*.so.*

%files -n libxalan-c-devel
%{_includedir}/xalanc/
%{_libdir}/libxalan*.so
%{_libdir}/cmake/XalanC
%{_libdir}/pkgconfig/xalan-c.pc

%changelog
* Mon Sep 28 2020 dmueller@suse.com
- update to 1.12:
  * Xerces-C++ versions 3.0 and newer are supported. Xerces-C++
  * Version 3.2.3 is the preferred stable release.
  * Addition of a CMake build for all supported platforms.
  * Rewrite of StyleBook XML documentation in Markdown, hosted at
  * https://apache.github.io/xalan-c/.
  * Removal of MacOS and Windows project files for old IDE versions.
  * Removal of Autoconf build.
  * Xalan-C++ now supports Microsoft Visual Studio 2019 and earlier
  * via the new CMake build, which replaces the old version-specific
  * project and solution files.
  * Xalan-C++ now also supports building with C++11, C++14 and C++17.
  * Cygwin and MinGW are known to be nonfunctional in this release.
  * Restoring full support will be a goal for 1.13.
- drop fix-ftbfs-ld-as-needed.diff,
    fix-testxslt-segfault.diff
    xalan-c-1.11-optflags.patch
    reproducible.patch
    xalan-c-parallel-build.patch : obsolete
* Fri May 19 2017 bwiedemann@suse.com
- Add reproducible.patch to have constant link-order
  and make build fully reproducible
* Tue May 17 2016 tchvatal@suse.com
- %%__isa_bits instead of ifarch conditional
* Fri May 13 2016 tchvatal@suse.com
- Cleanup a bit with spec-cleaner
- Disable ICU as no other distro does build with it
- Add patches to build with paralel make and respect ldflags
- Remove test/sample binaries instalation, not needed on resulting
  systems
- Add condition for aarch64 build
- Added patches:
  * fix-ftbfs-ld-as-needed.diff
  * fix-testxslt-segfault.diff
  * xalan-c-parallel-build.patch
- Removed patches, no longer needed:
  * xalan-c-1.11-fix_build.patch
  * xalan-c-1.11-fixes.patch
  * xalan-c-1.11-gcc4.patch
  * xalan-c-1.11-lib64.patch
* Tue Mar 10 2015 matwey.kornilov@gmail.com
- Update to 1.11
- Drop xalan-c-1.10.0-gcc46.patch: upstreamed
- Frop xalan-c-svn-20090415.patch: upstreamed
- Refresh and rename the following patches
  * xalan-c-1.10.0-lib64.patch -> xalan-c-1.11-lib64.patch
  * xalan-c-1.10.0-fix_build.patch -> xalan-c-1.11-fix_build.patch
  * xalan-c-1.10.0-optflags.patch -> xalan-c-1.11-optflags.patch
  * xalan-c-1.10.0-fixes.patch -> xalan-c-1.11-fixes.patch
  * xalan-c-1.10.0-gcc4.patch -> xalan-c-1.11-gcc4.patch
* Thu Dec 22 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use System/Libraries for shlibs
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Mon May  2 2011 idoenmez@novell.com
- Add xalan-c-1.10.0-gcc46.patch to fix compilation with gcc 4.6
* Sun Nov 15 2009 meissner@suse.de
- refresh patch with fuzz=0
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Wed Apr 15 2009 ro@suse.de
- rename subpackages (X to x)
- update to svn to try to build with current xerces
* Mon Sep  1 2008 aj@suse.de
- Do not build in parallel.
* Thu Aug 14 2008 prusnak@suse.cz
- cleaned spec file (and renamed libXalan-c-110 to libXalan-c110)
* Tue Dec 18 2007 zpetrova@suse.cz
- Fixed Requires of lib subpackage.
* Wed Oct  3 2007 zpetrova@suse.cz
- fixed build.
* Tue Aug  7 2007 mrueckert@suse.de
- revert %%check change
* Mon Aug  6 2007 mrueckert@suse.de
- fixed buildrequires (using the old package name. it is still
  provided)
- ldconfig should be run for the new library package libXalan-c-110
- move make test into %%check
* Mon Aug  6 2007 mrueckert@suse.de
- added provides/obsoletes for the package rename
* Mon Aug  6 2007 zpetrova@suse.cz
- split to libXalan-c-110, lib-Xalan-c-devel according to
  Shared library guidelines.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  9 2006 zpetrova@suse.cz
- update to 1.10
* Tue May  3 2005 uli@suse.de
- fixed to build with GCC4
* Tue Mar 22 2005 didge@suse.de
- added new patch by Robert Schiele (Bug #64605)
* Mon Jan 24 2005 ro@suse.de
- fix lib64 build
* Tue Jan 11 2005 didge@suse.de
- new version 1.9
* Mon Dec 20 2004 didge@suse.de
- removed soname patch as it isn't needed anymore
* Thu Dec  9 2004 didge@suse.de
- added patch by Robert Schiele to rename include path from xalan
  to xalanc
* Mon Aug  9 2004 didge@suse.de
- new version 1.8
- soname patch adapted
* Wed May 12 2004 didge@suse.de
- patch added to fix #40176
- fixed #40178 by adding expat to neededforbuild
* Fri Feb 13 2004 meissner@suse.de
- Fixed lib64 problem.
* Tue Feb 10 2004 didge@suse.de
- Update to version 1.7
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Fri Aug 29 2003 nashif@suse.de
- #29608: Symlink libs instead of copying them
* Tue Aug 26 2003 nashif@suse.de
- Reduced docs
* Tue Aug  5 2003 nashif@suse.de
- Update to version 1.6
* Thu May 29 2003 nashif@suse.de
- Update to version 1.5
* Tue Jan 21 2003 nashif@suse.de
- Adapted to use latest Xerces-c
- Updated sources to real 1.4
* Fri May 17 2002 nashif@suse.de
- Fixed for lib64
* Wed May 15 2002 nashif@suse.de
- Java not needed for build
* Tue May 14 2002 nashif@suse.de
- Update to 1.4 CVS which actually compiles
* Fri Mar  8 2002 sf@suse.de
- removed a wrong #define to build with gcc3.x
* Thu Jan 31 2002 nashif@suse.de
- Update to version 1.3
- Use the source from CVS (version 1.3)
- Create docs using doxygen
* Thu Oct 11 2001 nashif@suse.de
- Initial Release (1.2)
